"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.exporter = void 0;

var _fs = require("fs");

var _utils = require("../utils");

var exporter = {
  exportConnectorDefinition: function exportConnectorDefinition(def) {
    var stream = (0, _fs.createWriteStream)("def/connector.json");
    stream.write(JSON.stringify(def, null, '\t'));
    stream.end();
  },
  exportConnectorActions: function exportConnectorActions(actions) {
    var stream = (0, _fs.createWriteStream)("def/actions.js");
    stream.write("module.exports = {\n".concat(this._serializeActions(actions), "\n};"));
    stream.end();
  },

  /**
   * Returns the contents of the 'actions.js' file of the connector. It contains the implemented actions in a module.exports declaration.
   * @param connector a connector configuration file.
   */
  _serializeActions: function _serializeActions(actions) {
    var serializedContent = actions.map(function (action) {
      return {
        name: "'".concat(action.name, "'"),
        description: "'".concat(action.description, "'")
      };
    }).map(function (action) {
      return "\t".concat(action.name, ": ").concat(action.description, ",\n");
    }).reduce(function (sum, action) {
      return sum + action;
    }, '');
    return serializedContent.substring(0, serializedContent.length - 2);
  }
};
exports.exporter = exporter;